package edu.illinois.ncsa.paw.domain;

import javax.persistence.Entity;

import edu.illinois.ncsa.domain.AbstractBean;

/**
 * Stores the service provider name, url and job-id for a submitted job This can
 * be associated with a workflow step for obtaining status information about the
 * job.
 * 
 * @author Chris Navarro
 * @author Luigi Marini
 * 
 */
@Entity(name = "JobExecution")
public class JobExecution extends AbstractBean {

    private static final long serialVersionUID = 1L;

    /** Job Id associated with an execution */
    private String            jobId;

    /** Service provider (e.g. Gondola) */
    private String            provider;

    /** Service endpoint */
    private String            endpointUrl;

    /** Workflow step id */
    private String            stepId;

    public JobExecution() {

    }

    /**
     * Returns job id of the execution
     * 
     * @return job id
     */
    public String getJobId() {
        return jobId;
    }

    /**
     * Sets the job id of the execution
     * 
     * @param jobId
     *            sets the job id of the execution
     */
    public void setJobId(String jobId) {
        this.jobId = jobId;
    }

    /**
     * Returns the name of the service provider
     * 
     * @return Name of service provider
     */
    public String getProvider() {
        return provider;
    }

    /**
     * Sets the name of the service provider
     * 
     * @param provider
     *            sets the name of the service provider
     */
    public void setProvider(String provider) {
        this.provider = provider;
    }

    /**
     * Returns the endpoint of the service provider
     * 
     * @return the endpoint of the service provider
     */
    public String getEndpointUrl() {
        return endpointUrl;
    }

    /**
     * Sets the endpoint url of the service provider
     * 
     * @param endpointUrl
     *            sets the url of the service provider
     */
    public void setEndpointUrl(String endpointUrl) {
        this.endpointUrl = endpointUrl;
    }

    public String getStepId() {
        return stepId;
    }

    public void setStepId(String stepId) {
        this.stepId = stepId;
    }

}
